#!/bin/sh
#  Idlekiller 1.0   28-SEP-1995
#  David Mathog, Biology Division, Caltech
#  
#  This kills idle jobs on SGI screens after timeout idle
#  seconds, first giving a logout screen for timewarn seconds.
#
#  timeout defaults to 300 seconds = 5 minutes, but may be set with $1.
#    a value of zero disables idlekiller
#  timewarn defaults to 60 seconds = 1 minute, but may be set with $2.
#  timedelay defaults to 20 seconds, but maybe set with $3.  What this
#    does is delays for a bit before starting the main loop, this gives
#    terminal/console devices a chance to form before the first time stamp
#    is set.
#
#  The method is very simple. It will likely fail if there is no
#  activity on any device, which may be possible for some programs.
#  It will also fail if there is nonconsole activity via telnet, for instance.
#
#  The method cannot work for root, since it owns most devices
#
   if [ $USER = root ]
   then
      exit
   fi
#
#  initialize the assorted values
#
   timeout=${1-300}
   timewarn=${2-60}
   timedelay=${3-20}
   idle_timer=${HOME}/idle_timer
   zappo=`which endsession`
#
# initial time delay
#
   sleep $timedelay
#
#  start the timer loop, if there is a valid time to work with
#
   while [ $timeout -ne 0 ] 
   do
      touch $idle_timer
      sleep $timeout
#
#  check to make sure that the user has not logged out in the interim -
#  doing so does not stop idlekiller, so it must stop itself
#
   ps -ef | grep 4Dwm | grep $USER | grep -v grep
   if [ $? -eq 1 ]
   then
     exit
   fi
#
#  check for activity - any /dev file owned by USER that has changed
#  more recently than the idle_timer time stamp
#
      find /dev -user $USER -newer $idle_timer -print | grep dev >/dev/null
#
#  if there are NOT such files, it indicates an idle session
#
#  the time bomb does this:
#     sleep for timewarn
#     kill the parent shell (idlekiller)
#     force an endsession
#     exit (probably never gets that far)
#
      if [ $? -eq 1 ]
      then
        (sleep $timewarn ; kill $$; $zappo -f ; exit) &
        timebomb=$!
        $zappo
        kill -9 $timebomb
      fi  
   done
